==> Sim.DiffProc_3.7.tar.gz: Sim.DiffProc/R/zzz.r <==
## Fri Mar 10 17:25:05 2017
## Original file Copyright © 2017 A.C. Guidoum, K. Boukhetala
## This file is part of the R package Sim.DiffProc
## Department of Probabilities & Statistics
## Faculty of Mathematics
## University of Science and Technology Houari Boumediene
## BP 32 El-Alia, U.S.T.H.B, Algiers
## Algeria

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## A copy of the GNU General Public License is available at
## http://www.r-project.org/Licenses/
## Unlimited use and distribution (see LICENCE).
###################################################################################################


#############
#############
.noGenerics <- TRUE

.onLoad <- function(libname, pkgname)
          {
   library.dynam("Sim.DiffProc", pkgname, libname, local = FALSE) 
}

.onUnload <- function(libpath) {
    library.dynam.unload("Sim.DiffProc", libpath)
}

# .onAttach <- function(libname, pkgname) {
    # packageStartupMessage(paste0("This is package 'Sim.DiffProc', v",packageVersion(pkgname)));
# }

.onAttach <- function(library, pkg) {
    packageStartupMessage("Package 'Sim.DiffProc', version 3.7\nbrowseVignettes('Sim.DiffProc') for summary information.")
	invisible()
}

==> Sim.DiffProc_3.8.tar.gz: Sim.DiffProc/R/zzz.r <==
## Tue Aug 01 17:11:30 2017
## Original file Copyright © 2017 A.C. Guidoum, K. Boukhetala
## This file is part of the R package Sim.DiffProc
## Department of Probabilities & Statistics
## Faculty of Mathematics
## University of Science and Technology Houari Boumediene
## BP 32 El-Alia, U.S.T.H.B, Algiers
## Algeria

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## A copy of the GNU General Public License is available at
## http://www.r-project.org/Licenses/
## Unlimited use and distribution (see LICENCE).
###################################################################################################


#############
#############
.noGenerics <- TRUE

.onLoad <- function(libname, pkgname)
          {
   library.dynam("Sim.DiffProc", pkgname, libname, local = FALSE) 
}

.onUnload <- function(libpath) {
    library.dynam.unload("Sim.DiffProc", libpath)
}

# .onAttach <- function(libname, pkgname) {
    # packageStartupMessage(paste0("This is package 'Sim.DiffProc', v",packageVersion(pkgname)));
# }

.onAttach <- function(library, pkg) {
    packageStartupMessage("Package 'Sim.DiffProc', version 3.8\nbrowseVignettes('Sim.DiffProc') for more informations.")
	invisible()
}
